<?xml version="1.0" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:template match="/">
	<html>
		<head>
			<title>TuxPad Template</title>
			<link href="tuxpad.css" rel="stylesheet" />
		</head>
		<body>
			<h1 class="title">The 
				<u>
				<xsl:value-of select="Template/RootStructure/@Name" />
				</u> Tuxpad Template
			</h1>
			<p>
				<xsl:value-of select="Template/RootStructure/text()" />
			</p>
				<xsl:apply-templates select="Template/RootStructure/Properties" />
				Here follows the full structure of this document 
				<ul type="">
					<xsl:apply-templates select="Template/RootStructure/Structure" mode="tree" />
				</ul>
			<h1>Structure Reference</h1>
			<xsl:apply-templates select="//Structure">
				<xsl:sort select="@Name" />
			</xsl:apply-templates>
		</body>
	</html>
</xsl:template>

<xsl:template match="Structure">
	<a>
		<xsl:attribute name="NAME">
			<xsl:value-of select="@Name" />
		</xsl:attribute>	
	<h2>Structure: 
		<xsl:value-of select="@Name" />
	</h2>
	</a>	
	<p>
		<xsl:value-of select="@Hint" />
	</p>
	<p>
		<xsl:value-of select="text()" />
	</p>
	<xsl:apply-templates select="Properties" />
		<h3>Structure Information</h3>
		From this node you can add one of these structures:
		<ul type="">
			<xsl:apply-templates select="Structure" mode="list" />
			<xsl:apply-templates select="LinkStructure" mode="list" />
		</ul>
</xsl:template>

<xsl:template match="Properties">
	<h3>Properties</h3>
	<xsl:apply-templates />
</xsl:template>

<xsl:template match="TextProperty">
	
	<h4><xsl:value-of select="@Name" /></h4>
	<p>
		<xsl:value-of select="@Hint" />
	</p>
	<p>
		<xsl:value-of select="text()" />
	</p>	
</xsl:template>

<xsl:template match="BooleanProperty">
	
	<h4><xsl:value-of select="@Name" /></h4>
	<p>
		<xsl:value-of select="@Hint" />
	</p>
	<p>
		<xsl:value-of select="text()" />
	</p>	
</xsl:template>

<xsl:template match="ListProperty">
	<h4><xsl:value-of select="@Name" /></h4>
	<p>
		<xsl:value-of select="@Hint" />
	</p>
	<p>
		<xsl:value-of select="text()" />
	</p>	
	This property can take any one of these values:
	<ul>
		<xsl:apply-templates select="Item" />
	</ul>

</xsl:template>

<xsl:template match="Item">
	<li><xsl:value-of select="@Name" />. <xsl:value-of select="text()" /></li>
</xsl:template>
<xsl:template match="LinkStructure" mode="list">
	<li>
		<a>
			<xsl:attribute name="href">
				<xsl:value-of select="concat('#',@LinkTarget)" />
			</xsl:attribute>	
			<xsl:value-of select="@LinkTarget" />
		</a>
		(<xsl:value-of select="text()" />)
	</li>
</xsl:template>

<xsl:template match="Structure" mode="tree">
	<li>
		<a>
			<xsl:attribute name="href">
				<xsl:value-of select="concat('#',@Name)" /> 
			</xsl:attribute>	
			<xsl:value-of select="@Name" />
		</a>
		(<xsl:value-of select="@Hint" />)
		<ul>
		<xsl:apply-templates select="LinkStructure" mode="list" />
		<xsl:apply-templates select="Structure" mode="tree" />
		</ul>
	</li>
</xsl:template>

<xsl:template match="*" mode="list">
	<li>
		<a>
			<xsl:attribute name="href">
				<xsl:value-of select="concat('#',@Name)" /> 
			</xsl:attribute>	
			<xsl:value-of select="@Name" />
		</a>
		(<xsl:value-of select="@Hint" />)
	</li>
</xsl:template>

<!-- we are here -->
<xsl:template match="class">
	<h1>
	<xsl:value-of select="@namespace" />::<xsl:value-of select="@name" />
	</h1>
	<xsl:apply-templates select="note" />
	<xsl:apply-templates select="group" />
</xsl:template>

<xsl:template match="group">
	<h2><xsl:value-of select="@name" /> </h2>
	<xsl:apply-templates select="note" />
	<xsl:apply-templates select="function" />	
</xsl:template>

<xsl:template match="function">
	<h3>
		<xsl:value-of select="@return" /> 
		<xsl:value-of select="concat('',' ')" /> 
		<xsl:value-of select="@name" /> 
		(<xsl:apply-templates select="argument" mode="declare"/>)
	</h3>
	<xsl:apply-templates select="note" />
	<br />
	<div class="argument">
		<xsl:apply-templates select="argument" />		
	</div>	
</xsl:template>

<xsl:template match="argument">
	<h4><xsl:value-of select="@name" /> </h4>
	<xsl:apply-templates select="note" />
</xsl:template>

<xsl:template match="argument" mode="declare">
	<xsl:value-of select="@type" /> 
	<xsl:value-of select="concat('',' ')" /> 
	<u><xsl:value-of select="@name" /> </u>
	<xsl:value-of select="concat('',' ')" /> 
</xsl:template>

</xsl:stylesheet>

  
